@@ -270,6 +270,7 @@ thunar_util_expand_filename (const gchar  *filename,
   const gchar   *slash;
   gchar         *username;
   gchar         *pwd;
+  gchar         *variable;
   gchar         *result = NULL;
 
   g_return_val_if_fail (filename != NULL, NULL);
@@ -320,6 +321,25 @@ thunar_util_expand_filename (const gchar  *filename,
           replacement = passwd->pw_dir;
         }
 
+      /* generate the filename */
+      return g_build_filename (replacement, slash, NULL);
+    }
+  else if (*filename == '$')
+    {
+      /* examine the remainder of the variable and filename */
+      remainder = filename + 1;
+
+      /* lookup the slash at the end of the variable */
+      for (slash = remainder; *slash != '\0' && *slash != G_DIR_SEPARATOR; ++slash);
+
+      /* get the variable for replacement */
+      variable = g_strndup (remainder, slash - remainder);
+      replacement = g_getenv (variable);
+      g_free (variable);
+
+      if (replacement == NULL)
+        return NULL;
+
       /* generate the filename */
       return g_build_filename (replacement, slash, NULL);
     }
@@ -374,7 +394,7 @@ thunar_util_humanize_file_time (guint64          file_time,
                                 const gchar     *date_custom_style)
 {
   const gchar *date_format;
-  struct tm    tfile;
+  struct tm   *tfile;
   time_t       ftime;
   GDate        dfile;
   GDate        dnow;
@@ -385,8 +405,8 @@ thunar_util_humanize_file_time (guint64          file_time,
     {
       ftime = (time_t) file_time;
 
-      /* take a copy of the local file time */
-      tfile = *localtime (&ftime);
+      /* determine the local file time */
+      tfile = localtime (&ftime);
 
       /* check which style to use to format the time */
       if (date_style == THUNAR_DATE_STYLE_SIMPLE || date_style == THUNAR_DATE_STYLE_SHORT)
@@ -407,7 +427,7 @@ thunar_util_humanize_file_time (guint64          file_time,
               else /* if (date_style == THUNAR_DATE_STYLE_SHORT) */
                 {
                   /* TRANSLATORS: file was modified less than one day ago */
-                  return exo_strdup_strftime (_("Today at %X"), &tfile);
+                  return exo_strdup_strftime (_("Today at %X"), tfile);
                 }
             }
           else if (diff == 1)
@@ -420,7 +440,7 @@ thunar_util_humanize_file_time (guint64          file_time,
               else /* if (date_style == THUNAR_DATE_STYLE_SHORT) */
                 {
                   /* TRANSLATORS: file was modified less than two days ago */
-                  return exo_strdup_strftime (_("Yesterday at %X"), &tfile);
+                  return exo_strdup_strftime (_("Yesterday at %X"), tfile);
                 }
             }
           else
@@ -437,25 +457,25 @@ thunar_util_humanize_file_time (guint64          file_time,
                 }
 
               /* format the date string accordingly */
-              return exo_strdup_strftime (date_format, &tfile);
+              return exo_strdup_strftime (date_format, tfile);
             }
         }
       else if (date_style == THUNAR_DATE_STYLE_LONG)
         {
           /* use long, date(1)-like format string */
-          return exo_strdup_strftime ("%c", &tfile);
+          return exo_strdup_strftime ("%c", tfile);
         }
       else if (date_style == THUNAR_DATE_STYLE_YYYYMMDD)
         {
-          return exo_strdup_strftime ("%Y-%m-%d %H:%M:%S", &tfile);
+          return exo_strdup_strftime ("%Y-%m-%d %H:%M:%S", tfile);
         }
       else if (date_style == THUNAR_DATE_STYLE_MMDDYYYY)
         {
-          return exo_strdup_strftime ("%m-%d-%Y %H:%M:%S", &tfile);
+          return exo_strdup_strftime ("%m-%d-%Y %H:%M:%S", tfile);
         }
       else if (date_style == THUNAR_DATE_STYLE_DDMMYYYY)
         {
-          return exo_strdup_strftime ("%d-%m-%Y %H:%M:%S", &tfile);
+          return exo_strdup_strftime ("%d-%m-%Y %H:%M:%S", tfile);
         }
       else /* if (date_style == THUNAR_DATE_STYLE_CUSTOM) */
         {
@@ -463,7 +483,7 @@ thunar_util_humanize_file_time (guint64          file_time,
             return g_strdup ("");
 
           /* use custom date formatting */
-          return exo_strdup_strftime (date_custom_style, &tfile);
+          return exo_strdup_strftime (date_custom_style, tfile);
         }
     }
 
